#!/bin/bash

BACKUP_DATE=$(date +%Y%m%d%H%M%S)

if [ -d NEW/jre ]; then
  oldVersion=`cat jre/version.appup`
  newVersion=`cat NEW/jre/version.appup`
  echo "Update jre version $oldVersion to $newVersion"
  mkdir -p OLD
  backupdir=OLD/jre-$oldVersion-$BACKUP_DATE
  echo "Backup jre old version to $backupdir"
  mv jre $backupdir
  mv NEW/jre .
fi

chmod +x jre/bin/java
if [ ! -h java ]; then
  ln -sr jre/bin/java java
fi

if [ -d NEW/obsdeb ]; then
  oldVersion=`cat obsdeb/version.appup`
  newVersion=`cat NEW/obsdeb/version.appup`
  echo "Update obsdeb version $oldVersion to $newVersion"
  mkdir -p OLD
  backupdir=OLD/obsdeb-$oldVersion-$BACKUP_DATE
  echo "Backup obsdeb old version to $backupdir"
  mv obsdeb $backupdir
  mv NEW/obsdeb .
  chmod +x obsdeb/update.sh
  chmod +x obsdeb/launch.sh
fi

if [ -d NEW/i18n ]; then
  oldVersion=`cat i18n/version.appup`
  newVersion=`cat NEW/i18n/version.appup`
  echo "Update i18n version $oldVersion to $newVersion"
  mkdir -p OLD
  backupdir=OLD/i18n-$oldVersion-$BACKUP_DATE
  echo "Backup i18n old version to $backupdir"
  mv i18n $backupdir
  mv NEW/i18n .
fi

if [ -d NEW/help ]; then
  oldVersion=`cat help/version.appup`
  newVersion=`cat NEW/help/version.appup`
  echo "Update help version $oldVersion to $newVersion"
  mkdir -p OLD
  backupdir=OLD/help-$oldVersion-$BACKUP_DATE
  echo "Backup help old version to $backupdir"
  mv help $backupdir
  mv NEW/help .
fi

if [ -d NEW/report ]; then
  oldVersion=`cat report/version.appup`
  newVersion=`cat NEW/report/version.appup`
  echo "Update report version $oldVersion to $newVersion"
  mkdir -p OLD
  backupdir=OLD/report-$oldVersion-$BACKUP_DATE
  echo "Backup report old version to $backupdir"
  mv report $backupdir
  mv NEW/report .
fi

if [ -d plugins/NEW ]; then
  for i in plugins/NEW/* ; do
    if [ -d "$i" ]; then
      pluginName="${i##*/}"
      pluginPath=plugins/$pluginName
      pluginNewPath=plugins/NEW/$pluginName
      
      echo $pluginName
      echo $pluginPath
      echo $pluginNewPath
      
      if [ ! -f $pluginNewPath/version.appup ]; then
	echo "$pluginNewPath/version.appup not found. update aborted"
      else 
	newVersion=`cat $pluginNewPath/version.appup`
	if [ -d pluginPath ]; then
	  oldVersion=`cat $pluginPath/version.appup`
	  backupdir=plugins/OLD/$pluginName-$oldVersion-$BACKUP_DATE
	  echo "Update plugin $pluginName version $oldVersion to $newVersion. Old plugin keep in $backupdir"
	  mkdir -p plugins/OLD
	  mv $pluginPath $backupdir
	else
	  echo "Install plugin $pluginName version $newVersion"
	fi
	mv $pluginNewPath $pluginPath
      fi
    fi
  done
fi

rm -rf NEW
rm -rf plugins/NEW

if [ -f obsdeb/external_backup.sh ]; then 
  mv obsdeb/external_backup.sh . 
fi